@@ -39,22 +39,22 @@ static RUNTIME: LazyLock<tokio::runtime::Runtime> = LazyLock::new(|| {
 /// @see opendal_operator_free This function frees the heap memory of the operator
 ///
 /// \note The opendal_operator actually owns a pointer to
-/// an opendal::BlockingOperator, which is inside the Rust core code.
+/// an opendal::blocking::Operator, which is inside the Rust core code.
 ///
 /// \remark You may use the field `ptr` to check whether this is a NULL
 /// operator.
 #[repr(C)]
 pub struct opendal_operator {
-    /// The pointer to the opendal::BlockingOperator in the Rust code.
+    /// The pointer to the opendal::blocking::Operator in the Rust code.
     /// Only touch this on judging whether it is NULL.
     inner: *mut c_void,
 }
 
 impl opendal_operator {
-    pub(crate) fn deref(&self) -> &core::BlockingOperator {
+    pub(crate) fn deref(&self) -> &core::blocking::Operator {
         // Safety: the inner should never be null once constructed
         // The use-after-free is undefined behavior
-        unsafe { &*(self.inner as *mut core::BlockingOperator) }
+        unsafe { &*(self.inner as *mut core::blocking::Operator) }
     }
 }
 
@@ -77,7 +77,7 @@ impl opendal_operator {
     #[no_mangle]
     pub unsafe extern "C" fn opendal_operator_free(ptr: *const opendal_operator) {
         if !ptr.is_null() {
-            drop(Box::from_raw((*ptr).inner as *mut core::BlockingOperator));
+            drop(Box::from_raw((*ptr).inner as *mut core::blocking::Operator));
             drop(Box::from_raw(ptr as *mut opendal_operator));
         }
     }
@@ -86,15 +86,13 @@ impl opendal_operator {
 fn build_operator(
     schema: core::Scheme,
     map: HashMap<String, String>,
-) -> core::Result<core::Operator> {
-    let mut op = core::Operator::via_iter(schema, map)?.layer(core::layers::RetryLayer::new());
-    if !op.info().full_capability().blocking {
-        let runtime =
-            tokio::runtime::Handle::try_current().unwrap_or_else(|_| RUNTIME.handle().clone());
-        let _guard = runtime.enter();
-        op = op
-            .layer(core::layers::BlockingLayer::create().expect("blocking layer must be created"));
-    }
+) -> core::Result<core::blocking::Operator> {
+    let op = core::Operator::via_iter(schema, map)?.layer(core::layers::RetryLayer::new());
+
+    let runtime =
+        tokio::runtime::Handle::try_current().unwrap_or_else(|_| RUNTIME.handle().clone());
+    let _guard = runtime.enter();
+    let op = core::blocking::Operator::new(op)?;
     Ok(op)
 }
 
@@ -164,7 +162,7 @@ pub unsafe extern "C" fn opendal_operator_new(
     match build_operator(scheme, map) {
         Ok(op) => opendal_result_operator_new {
             op: Box::into_raw(Box::new(opendal_operator {
-                inner: Box::into_raw(Box::new(op.blocking())) as _,
+                inner: Box::into_raw(Box::new(op)) as _,
             })),
             error: std::ptr::null_mut(),
         },
